function compare3Transients(fname1,fname2,fname3)
% plotTransients  Plot Tb(t) and f(t) data saved from a heat sink simulation

if nargin<1,  fname1='HF_LB700_bB150_sw150_ts750_scalars.mat';  end
if nargin<2,  fname2='HF_LB850_bB050_sw200_ts750_scalars.mat';  end
if nargin<3,  fname3='HF_LB887_bB012_sw275_ts750_scalars.mat';  end

% load(fname1);  t1 = tt;  Tb1 = TPROBE(:,1);   f1 = MELTFRAC;
% load(fname2);  t2 = tt;  Tb2 = TPROBE(:,1);   f2 = MELTFRAC;
% load(fname3);  t3 = tt;  Tb3 = TPROBE(:,1);   f3 = MELTFRAC;

theFiles = strvcat(fname1,fname2,fname3);
fig = [];
symb = strvcat('k:','k--','k-')


for i=1:size(theFiles,1);
	fname = theFiles(i,:);
	if findstr(fname,'scalar')
		load(fname);
    istop = min( find(tt==0) ) - 1;
    if isempty(istop),  istop=length(tt);  end
		% fprintf('scalar data from %s\n',theFile);
		% --- Extract values from the file name
		LB = getValInStr(fname,'LB','_')/1000;
		bB = getValInStr(fname,'bB','_')/1000;
		sw = getValInStr(fname,'sw','_')/1000;

		[fig,is,ts] = doPlot(fig,tt(1:istop),TPROBE(1:istop,1),MELTFRAC(1:istop),LB,bB,sw,symb(i,:));
    istar(i) = is;
    tstar(i) = ts;
    Tbs(i) = TPROBE(is,1);
	end
end

axTb = subplot(1,2,1);
grid('on');  xlabel('time (s)');  ylabel('T_b  (C)','Rotation',0)
axis([0 750 0 100]);
set(axTb,'XTick',[0 250 500 750]);
set(axTb,'xTickLabel',strvcat('0','250','500','750'))
legend('A','B','Opt',4)
hold on
plot(tstar(1),Tbs(1),'ko',tstar(2),Tbs(2),'ko',tstar(3),Tbs(3),'ko')

axf = subplot(1,2,2);
grid('on');  xlabel('time (s)');  ylabel('f','Rotation',0)
axis([0 750 0 1])
set(axf,'XTick',[0 250 500 750]);
set(axf,'xTickLabel',strvcat('0','250','500','750'))
legend('A','B','Opt',4)



% ============================================================
function [fig,istar,tstar] = doPlot(fig,t,Tb,f,LB,bB,sw,symb)

if isempty(fig), 	fig = figure;  end
figure(fig);

% --- Find tstar, tinf, and fstar.  Set safe values if not found
istar = min( find(Tb>80) ) - 1;
iinf  = min( find(f>=1) ) - 1;
if isempty(istar)
  tstar = -t(end);  fstar = -1;
  fprintf('\n\tistar not found:  min(Tb), max(Tb), max(t) = %g  %g %g\n',min(Tb),max(Tb),max(t))
else
  tstar = t(istar);   fstar = f(istar);
end
if isempty(iinf)
  tinf = -t(end);
else
  tinf = t(iinf);
end
fprintf('%8.5f  %8.5f  %8.5f  %8.2f  %8.2f  %8.6f\n',LB,bB,sw,tstar,tinf,fstar);

% --- Use two subplots inside figure window that is saved
subplot(1,2,1);
hold on
plot(t,Tb,symb)
% if tstar>0,  plot(t(istar),Tb(istar),'o');  end

subplot(1,2,2);
hold on
plot(t,f,symb)

% =======================================================================
function v = getValInStr(s,sL,sr)
% getValInStr  Get value embedded in a string
%
% Synopsis:  v = getValInStr(s,sL,sr)
%
% Input:  s = string
%         sL = string that brackets value on the left
%         sr = string that brackets value on the right
%
% Ouput:  v = value embedded in string, and surrounded by sL and sr
%
% Example:  If s = 'abc_x100_y200rst', then v = getValInStr(s,'x','_')
%           returns the numerical value 100, and v = getValInStr(s,'y','rst')
%           returns the numerical value 200

% --- Find indices in string that 
ib = 1 + (length(sL)-1) + max(strfind(s,sL)); %  index of beginning of str representation of value
ie = ib + min(strfind(s(ib:end),sr)) - 2;   %  end of str representation
v = str2num(s(ib:ie));
if isempty(v)
  warning(sprintf('Numerical value not found:  string is %s',s(ib:ie)));
end


% =====================

function notUsed


istar1 = min( find(Tb1>80) ) - 1;  iinf1 = min( find(f1>=1) ) - 1;
istar2 = min( find(Tb2>80) ) - 1;  iinf2 = min( find(f2>=1) ) - 1;
istar3 = min( find(Tb3>80) ) - 1;  iinf3 = min( find(f3>=1) ) - 1;
fprintf('\n Case      tstar    tinf     fstar\n')
fprintf('    A   %8.2f   %8.6f   %8.2f\n',t1(istar1),t1(iinf1),f1(istar1));
fprintf('    B   %8.2f   %8.6f   %8.2f\n',t2(istar2),t2(iinf2),f2(istar2));
fprintf('   opt  %8.2f   %8.6f   %8.2f\n',t3(istar3),t3(iinf3),f3(istar3));

figure
ax1 = subplot(1,2,1);
plot(t1,Tb1,'b:',t2,Tb2,'r--',t3,Tb3,'k-')
grid('on');  xlabel('time (s)');  ylabel('T_b(C)','Rotation',0)
axis([0 750 0 100]);
set(ax1,'XTick',[0 250 500 750]);
set(ax1,'xTickLabel',strvcat('0','250','500','750'))
fprintf('max(t1) = %f   max(t2) = %f\n',max(t1),max(t2));
legend('A','B','opt',4);
hold on
plot(t1(istar1),Tb1(istar1),'ko',t2(istar2),Tb2(istar2),'ko',t3(istar3),Tb3(istar3),'ko');
hold off

ax2 = subplot(1,2,2);
plot(t1,f1,'b:',t2,f2,'r--',t3,f3,'k-')
grid('on');  xlabel('time (s)');  ylabel('f','Rotation',0)
axis([0 750 0 1])
set(ax2,'XTick',[0 250 500 750]);
set(ax2,'xTickLabel',strvcat('0','250','500','750'))
legend('A','B','opt',4);

