function [del,Texact] = exact(grid,T,tran)
% exact  Exact solution to Neumann problem:  delta(t)

persistent psi


[rho,cps,cpl,ks,kl,lat,Tm] = HTstefan('properties');
alphas = ks/rho/cps;  %  thermal diffusivity for solid
alphal = kl/rho/cpl;  %	 thermal diffusivity for liquid
gam = sqrt(alphal/alphas);

% --- Get psi value only if it hasn't been found before.
%     psi is persistent, meaning that it's value is retained
%     whenever this function has been executed in the current
%     MATLAB session (need a `clear psi' in command window between
%     runs)
if tran.dt==tran.t
  options = optimset('Display','off');
  % psi = fzero('func',1,options,T,Tm,lat,cps,cpl,gam);
  p0 = 1;
  SteS = cpl*(Tm-T.ebcval(1))/lat;
  SteL = cps*(T.wbcval(1)-Tm)/lat;
  psi = fzero('neumannFzero2',p0,optimset('Display','off'),SteL,SteS,gam);
end
del = 2*psi*sqrt((alphal*tran.t));


%---------develop an exact temperature solution-----------

for j = 1:grid.ny
   for i = 1:grid.nx
      Tind = (j-1)*grid.nx + i;
      erfnuml = erf(grid.x(i)/(2*sqrt(alphal*tran.t))); 
      erfnums = erf(grid.x(i)/(2*sqrt(alphas*tran.t)));
      if grid.x(i)<del
      	Tex(Tind) = T.wbcval(j) + (Tm - T.wbcval(j))*erfnuml/erf(psi);       
      elseif grid.x(i)>del
         Tex(Tind) = T.ebcval(j) + (Tm - T.ebcval(j))*(erfnums-1)/(erf(psi*gam)-1);
      elseif grid.x(i)==del
         Tex(Tind) = Tm;
      else
         error('there is a problem with the relation between the exact melt front and the grind dim.')
      end
   end   
end

Texact(:,1) = Tex(:);  %make sure Texact is a column vector