function [del,Texact] = exactste(grid,T,tran)
% exact  Exact solution to Stefan problem undergoing solidification:  delta(t)

global MELTING_CURVE_FCN
persistent lam idstop T0

if tran.t==tran.dt
   lam = [];
   Texact = zeros(size(T.f));
   T0 = T.wbcval(1);
end

[rho,cps,cpl,ks,kl,lat,Tm] = feval(MELTING_CURVE_FCN,'properties');
alphas = ks/(rho*cps);  %  thermal diffusivity for solid

% --- Get lam value only if it hasn't been found before.
%     lam is persistent, meaning that it's value is retained
%     whenever this function has been executed in the current
%     MATLAB session (need a `clear lam' in command window between
%     runs)
if isempty(lam)
  options = optimset('Display','off');
  p0 = 1;
  SteL = cps*(T.wbcval(1)-Tm)/lat;
  lam = fzero('StefanFzero',p0,optimset('Display','off'),SteL);
end

del = 2*lam*sqrt((alphas*tran.t));

%---------------compute exact temperature profile-----------------

for j = 1:grid.ny
   for i = 1:grid.nx
      Tind = (j-1)*grid.nx + i;
      Tex(Tind) = T0 + (Tm-T0)/erf(lam)*erf(grid.x(i)/(2*sqrt(alphas*tran.t)));       
      
   end   
end

Texact(:,1) = Tex(:);  %make sure Texact is a column vector
   