function rho = fivePtResidual(nx,ny,ap,ae,aw,an,as,x,b)
% fivePtResidual  Computes ||b - Ax||_2 for the five-point difference scheme using
%                 compass-point notation.  The coefficient array consists of
%     diagonalswhich are stored in the vectors ap, ae, aw, an, and as.
%     Nodes are numbered with natural ordering.  nx and ny are the
%     number of interior nodes (control volumes) in the x and y
%     directions, respectively.  Under these conditions an element of
%     the r vector is computed with
%
%	    r(i) =  b + as(i)*x(i-nx) + aw(i)*x(i-1) - ap(i)*x(i)
%                 + an(i)*x(i+nx) + ae(i)*x(i+1)
%
% Synopsis:  rho = fivePtResidual(nx,ny,ap,ae,aw,an,as,x,b)
%
% Input:  nx,ny = number of unknowns on finite difference grid in x and y directions.
%         ap,ae,aw,an,as = diagonals of the coefficient matrix corresponding to the following
%                 stencil.  Mesh points are referred to with compass point notation where
%                 neighors of point "P" are "west" = (i-1,j), "north" = (i,j+1), etc.
%         x = input vector
%         y = output vector (is provided as input to allow reuse w/out memory allocation)
%
% Output:  rho = ||b - A*x||_2, i.e. the L2 norm of the residual vector

% Note:  A*x is evaluated with fivePtAx

rho = norm(b-fivePtAxVec(nx,ny,ap,ae,aw,an,as,x));

