function [ae,aw,an,as] = fvcoeff(grid,phi);
% fvcoeff  CVFD coefficients for diffusion a non-uniform two-dimensional mesh
%          with non-uniform diffusion coefficients.  Per unit volume formulation is used
%
%  Gerald Recktenwald, Portland State University, Mechanical Engineering Dept.
%  gerry@me.pdx.edu
%  May 1994, June 1999, May 2000, Sept 2002

%  Allocate memory and initilize coefficients
%  Copying of structure variables is inefficient.  MATLAB needs pointers
nx = grid.nx;  ny = grid.ny;  nn = nx*ny;
x = grid.x;    xu = grid.xu;  dx = grid.dx;
y = grid.y;    yv = grid.yv;  dy = grid.dy;
ae=zeros(nn,1);  aw=ae;  an=ae;  as=ae;  %   gam = phi.gamma;

%  Diffusion coefficients for the north face of interior control volumes
for j=1:ny-1
  delyn =  y(j+1)  - y(j);
  bbeta = (yv(j+1) - y(j))/delyn;
  np = (1:nx)' + (j-1)*nx;   %  for i=1:nx,  np = i + (j-1)*nx
  gamma_n = phi.gamma(np).*phi.gamma(np+nx)./(bbeta*phi.gamma(np+nx) + (1-bbeta)*phi.gamma(np));
  an(np) = gamma_n/(delyn*dy(j));
  as(np+nx) = gamma_n/(delyn*dy(j+1)); 
end

%  Diffusion coefficients for the east face of interior control volumes
for i=1:nx-1
  delxe =  x(i+1)  - x(i);
  bbeta = (xu(i+1) - x(i))/delxe;
  np = i + ( ( (1:ny)' - 1) *nx );  %  for j=1:ny,  np = i + (j-1)*nx
  gamma_e = phi.gamma(np).*phi.gamma(np+1)./(bbeta*phi.gamma(np+1) + (1-bbeta)*phi.gamma(np));
  ae(np) = gamma_e/(delxe*dx(i));
  aw(np+1) = gamma_e/(delxe*dx(i+1));
end
