function [F,X,Y] = make2DijFieldStruct(f,g)
% make2DijFieldObj  Convert vector of interior values to matrix where (i,j) <==> (y,x)
%                   This function is an struct-based interface to the make2DijField function
%
% Synopsis:  Z = make2DijFieldObj(f,g)
%            [Z,X,Y] = make2DijFieldObj(f,g)
%
% Input:  f = 2D field struct
%         g = 2D field struct
%
% Output: F = matrix constructed of interior and boundary values of the input u field.
%             The rows and columns of F correspond to a 2D Cartesian mesh the origin in
%             the lower left corner.  F is created in such a way that mesh(F), surf(F), etc
%             produce plots that look like they belong on the finite-volume mesh defined
%             by the x and y vectors input to this routine.
%         X,Y = (optional) matrices of mesh implied by the structure of F.  F(j,i) is the
%             value of the u field at X(j,i) and Y(j,i), which corresponds to the CV
%             located at x(i) and y(j).

if nargout==1
  F = make2DijField(f.nx,f.ny,g.x,g.xu,g.y,g.yv,f.f,f.ebcval,f.wbcval,f.nbcval,f.sbcval);
else
  [F,X,Y] = make2DijField(f.nx,f.ny,g.x,g.xu,g.y,g.yv,f.f,f.ebcval,f.wbcval,f.nbcval,f.sbcval);
end
