function f = neumannFzero(psi,SteL,SteS,gam)
% neumannFzero  Objective function for Newumann phase change problem, f(psi) = 0
%               Used with fzero to find f(psi)=0
%
% Input:  psi = dimensionless variable to be solved for with fzero
%         SteL = Stefan number for liquid phase
%         SteS = Stefan number for solid phase
%         gam = sqrt(alphaL/alphaS); alpha = thermal diffusivity; L = liquid, S = solid
%
% Output:  Value of f(psi).
%
% Note:  routine is vectorized so that vector of psi values can be input
rtpi = sqrt(pi);
f = SteS - (1 - SteL./(rtpi*psi.*exp(-psi.^2).*erf(psi))) .* (rtpi*psi*gam) ...
           .* (erf(psi*gam) - 1)./exp(-psi.^2 *gam^2);
