function f = neumannFzero2(psi,SteL,SteS,gam)
% neumannFzero2  Objective function for Neumann phase change problem, f(psi)=0
%                Used with fzero to find psi such that f(psi) = 0
%
% Synopsis:  f = neumannFzero2(psi,SteL,SteS,gam)
%
% Input:  psi = dimensionless variable to be solved for with fzero
%         SteL = Stefan number of liquid phase
%         SteS = Stefan number of solid phase
%         gam = sqrt(alphaL/alphaS); alpha = thermal diffusivity, L = liquid, S = solid
%
% Output:  value of f(psi)
%
% Note: Routine is vectorized so that a vector of psi values can be input
%rtpi = sqrt(pi);
%psierf = psi.*erf(psi);
%psigam = psi*gam;
%f = psierf*SteS - (psierf - SteL./(rtpi*exp(-psi.^2))) .* (rtpi*psigam) ...
%      .* (erf(psigam)-1)./exp(-psigam.^2);

f = SteS*psi*erf(psi) - (psi*erf(psi) - SteL/(sqrt(pi)*exp(-psi^2)))*(sqrt(pi)*psi*gam)*(erf(psi*gam)-1)/exp(-psi^2*gam^2);