function phi = new2DFieldStruct(nx,ny)
% new2DFieldStruct  Preallocate a 2D field structure
%
% Synopsis:  phi = new2DFieldStruct(nx,ny)
%
% Input  nx,ny = number of *interior* nodes in x and y directions

if nargin<2
  error('To create a 2D Field struct, nx and ny must be specified');
end

% --- Dummy variables used to initial boundary vectors
%     Note that east and west boundaries store values in column vectors
%     and north south boundaries store values in row vectors
%     Default is BC type = 1 for Dirichlet boundary condition
%     and value = 0 on boundary
ewtype = ones(ny,1);  ewval = zeros(size(ewtype));  %  ny nodes on east and west boundaries
nstype = ones(1,nx);  nsval = zeros(size(nstype));  %  nx nodes on north and south boundaries

f = zeros(nx*ny,1);      %  interior values only

phi = struct('nx',nx,'ny',ny,...    %  number of internal nodes in x and y directions
             'nonlinear',0,...      %  flag indicating whether nonlinear iterations are needed
             'iter',0,...           %  current index of nonlinear iterations
             'maxit',1,...          %  max number of nonlinear iterations to perform
             'rtol',5e-4,...        %  absolute tolerance on residual for nonlinear iterations
             'upwind','cds',...     %  upwinding scheme
             'ebctype',ewtype,...   %  east boundary type, Default = Dirichlet
             'ebcval',ewval,...     %  value of phi at boundary
             'ebcflux',ewval,...    %  value of flux at value
             'ebchval',ewval,...		%  value of heat transfer coeff. 
             'ebctamb',ewval,...		%  value of ambient temp for convection
             'wbctype',ewtype,...
             'wbcval',ewval,...
             'wbcflux',ewval,...
             'wbchval',ewval,...
             'wbctamb',ewval,...
             'nbctype',nstype,...      %  north boundary type
             'nbcval',nsval,...
             'nbcflux',nsval,...
             'nbchval',nsval,...
             'nbctamb',nsval,...
             'sbctype',nstype,...      %  south boundary type
             'sbcval',nsval,...
             'sbcflux',nsval,...
             'sbchval',nsval,...
             'sbctamb',nsval,...
             'f',f,...                    %  internal nodal values
             'gamma',ones(size(f)),...    %  diffusion coefficient
             'src',zeros(size(f)),...     %  constant source term
             'srcp',[],...                %  source term coefficient for phi
             'rhocp',ones(size(f)),...    %  rho*cp product for current time step
             'timeMethod','implicit'...   %  time step scheme 
           );
