function tran = newTimeStepControl(tstop,dt)
% newTimeStepControl  Preallocate a transient condition structure
%
% Synopsis:  tran = newTimeStepControl(tstop,dt)
%
% Input  tstop,dt = time to stop program, timestep for each iteration

if nargin<2
  error('To create a time step structure, tstop and dt must be specified');
end

% --- Dummy variables used to initial boundary vectors
maxStep = ceil(tstop/dt);				%	maximum number of iterations

tran = struct('t',0,...                     %  current time
   			      'dt',dt,...                   %  amount of time between iterations
              'tstop',tstop,...             %  time for scheduled program stop
              'istep',0,...                 %  current time step
              'maxStep',maxStep,...         %  max number of time steps
              'tsteps',zeros(maxStep,1));   %  Time at each time step in the simulation	
