function plotContourStruct(field,grid,values)
% plotContour  Plot a 2D contour.  Uses built-in contourc() and plot() functions
%              Field values are defined as 2Dfield and 2Dgrid structs

debug = 0;

% --- Let MATLAB find the points along a contour
Z = make2DijFieldStruct(field,grid);   %  convert field struct to a matrix of field values
if length(values)==1
  C = contourc(Z,[values values]);     %  Get contour matrix for one contour level
else
  C = contourc(Z,values);              %  Get contour matrix for list of contour levels
end
[mc,nc] = size(C);
if debug,  fprintf('\nC has %d rows and %d columns\n',mc,nc);  end



% --- Loop over segments of contours
ibeg = 2;                %  row index of first data pair for current contour
holdstate = ishold;
while ibeg<nc
  % --- Get descriptive data about this group of points on this contour
	lev = C(1,ibeg-1);     %  level of the current contour
	np = C(2,ibeg-1);      %  number of points in the (x,y) data set that defines the contour
  iend = ibeg+np-1;      %  row index of first data pair in the contour
  if debug, fprintf('\t lev,np,iend = %6d %6d %6d\n',lev,np,iend);  end
  
  % --- Extract the contour points for this segment from C, and plot the segment.
	xc = C(1,ibeg:iend);
	yc = C(2,ibeg:iend);
  if ibeg>2 & ~holdstate,  hold on;  end
  plot(xc,yc,'.');
  ibeg = iend + 2;     %  prepare for next contour segment

  % --- Add a label.  Heuristic rule for locating label: put it at top of loop
  it = find(yc==max(yc));  %  index of point for text label:  x(it), y(it)
  text(xc(it),yc(it),sprintf('v = %-6.2f',lev));
end
if ~holdstate, hold off;  end