function testCVFDprobe
% testCVFDprobe  Test the routine used to interpolate between mesh points

% --- Define the grid
Lx = 6.3;
Ly = 2.2;
nx = 7;
ny = 9;
grid = new2DGridStruct(nx,ny,Lx,Ly);
%	if debug,  printGrid(grid);   end

% --- Allocate memory for, and set BC for field variables
phi = new2DFieldStruct(nx,ny);
phi.gamma = ones(size(phi.f));


% --- Generate a planar z = f(x,y)
for i=1:grid.nx
	for j=1:grid.ny
		n = i + (j-1)*grid.nx;
		phi.f(n) = planeFun(grid.x(i),grid.y(j));
	end
end
for i=1:grid.nx
	phi.sbcval(i) = planeFun(grid.x(i),0);
	phi.nbcval(i) = planeFun(grid.x(i),grid.Ly);
end
for j=1:grid.ny
	phi.ebcval(j) = planeFun(grid.Lx,grid.y(j));
	phi.wbcval(j) = planeFun(0,grid.y(j));
end


% +++++++++++++++++
%  Debug:  enter single problem point here, and step through code
% xi = 6.19107;
% yi = 2.2;
% fi = cvfdProbe(xi,yi,grid,phi);

% +++++++++++++++++

% --- Sample random points
nt = 7;
xi = Lx*rand(nt,1);
yi = Ly*rand(nt,1);
fprintf('   i    j     xi(i)     yi(j)     error\n');
err = zeros(length(xi),length(yi));
for i=1:length(xi)
	for j=1:length(yi)
		fi = cvfdProbe(xi(i),yi(j),grid,phi);
		err(i,j) = fi - planeFun(xi(i),yi(j));
		fprintf(' %3d  %3d %8.4f   %8.4f   %12.3e\n',i,j,xi(i),yi(j),err(i,j));
	end
end
[emaxx,imax] = max(max(abs(err')));
[emaxy,jmax] = max(max(abs(err)));
fprintf('\nMaximum error from random samples = %12.4e  %12.4e\n',emaxx,emaxy);
fprintf('\toccurs at i=%d  j=%d\n',imax,jmax);

% --- Make sure boundaries are tested
fprintf('\n\nNorth boundary tests:\n');
yb = grid.Ly;
for i=1:length(xi)
	fi = cvfdProbe(xi(i),yb,grid,phi);
	err(i,j) = fi - planeFun(xi(i),yb);
	fprintf(' %3d  %3d %8.4f   %8.4f   %12.3e\n',i,j,xi(i),yb,err(i,j));
end
fprintf('\n\nSouth boundary tests:\n');
yb = 0;
for i=1:length(xi)
	fi = cvfdProbe(xi(i),yb,grid,phi);
	err(i,j) = fi - planeFun(xi(i),yb);
	fprintf(' %3d  %3d %8.4f   %8.4f   %12.3e\n',i,j,xi(i),yb,err(i,j));
end

fprintf('\n\nWest boundary tests:\n');
xb = 0;
for j=1:length(yi)
	fi = cvfdProbe(xb,yi(j),grid,phi);
	err(i,j) = fi - planeFun(xb,yi(j));
	fprintf(' %3d  %3d %8.4f   %8.4f   %12.3e\n',i,j,xb,yi(j),err(i,j));
end
fprintf('\n\nWest boundary tests:\n');
xb = grid.Lx;
for j=1:length(yi)
	fi = cvfdProbe(xb,yi(j),grid,phi);
	err(i,j) = fi - planeFun(xb,yi(j));
	fprintf(' %3d  %3d %8.4f   %8.4f   %12.3e\n',i,j,xb,yi(j),err(i,j));
end

% --- Test corners
fprintf('\nSouthwest corner:\n');
xi = 0.5*grid.x(1);
yi = 0.5*grid.y(1);
fi = cvfdProbe(xi,yi,grid,phi);
err = fi - planeFun(xi,yi);
fprintf('      %8.4f   %8.4f   %12.3e\n',xi,yi,err);

fprintf('\nNorthhwest corner:\n');
xi = 0.5*grid.x(1);
yi = grid.y(ny) + 0.5*(grid.y(ny+1)-grid.y(ny));
fi = cvfdProbe(xi,yi,grid,phi);
err = fi - planeFun(xi,yi);
fprintf('      %8.4f   %8.4f   %12.3e\n',xi,yi,err);

fprintf('\nSoutheast corner:\n');
xi = grid.x(nx) + 0.5*(grid.x(nx+1)-grid.x(nx));
yi = 0.5*grid.y(1);
fi = cvfdProbe(xi,yi,grid,phi);
err = fi - planeFun(xi,yi);
fprintf('      %8.4f   %8.4f   %12.3e\n',xi,yi,err);

fprintf('\nNortheast corner:\n');
xi = grid.x(nx) + 0.5*(grid.x(nx+1)-grid.x(nx));
yi = grid.y(ny) + 0.5*(grid.y(ny+1)-grid.y(ny));
fi = cvfdProbe(xi,yi,grid,phi);
err = fi - planeFun(xi,yi);
fprintf('      %8.4f   %8.4f   %12.3e\n',xi,yi,err);



% ===================================================
function z = planeFun(x,y)

z = 2.7*x + 8.2*y - 4.63;
