function meltContourPlots(dirname,rL,rs,rb)
% meltContourPlots  Draw melt contours for data in sequence of .mat files
%
% Synopsis:  meltContourPlots(dirname)
%            meltContourPlots(dirname,rL,rs,rb)
%
% Input:  dirname = directory containing the .mat files
%         rL,rw,rb = dimensionless size of the fin. rL = L/B = length (vertical
%                    direction) of fin divided by domain height

if nargin<1
	D = dir('*.mat');
else
	D = dir(sprintf('%s/*.mat',dirname));
end

fig = [];
minPixels=100;
for i=1:size(D,1)
  if nargin<1
	  fname = D(i).name
  else
    fname = sprintf('%s/%s',dirname,D(i).name)
  end
	if findstr(fname,'contour')
		load(fname);
		fprintf('contours for t = %8.3f\n',tran.t);
		[fig,nx,ny] = doPlots(fig,G,ggrid,tran,minPixels);
	end
end
% --- Add outline of the fin
if nargin>1
  % --- (xf,yf) are coordinates of polygon representing the fin
  L = rL*ggrid.Ly;
  w = ggrid.Lx;
  s = rs*w;
  b = rb*ggrid.Ly;
  xf = [0 0 s s w w 0]*nx/ggrid.Lx;
  yf = [0 L L b b 0 0]*ny/ggrid.Ly;
  fill(xf,yf,[0.8 0.8 0.8]);
end
hold off

% ============================================
function [fig,nx,ny] = doPlots(fig,G,grid,tran,minPixels)

if isempty(fig)
	fig = figure;
end
figure(fig);
hold on

fprintf('\n\tDrawing contours at t = %f  istep = %d\n',tran.t,tran.istep);
clabel = sprintf('%-5.0f',tran.t);
fixLength = 5.0e-3;  %  fixLength allows comparison of domains of different size
[nx,ny] = meltContour(G,grid.x,grid.xu,grid.y,grid.yv,0.5,clabel,minPixels,fixLength);
set(fig,'Name','Melting Front Contours');
set(gca,'XtickLabel',[],'Xtick',[]);   %  Turn off tick labels because they are pixel
set(gca,'YtickLabel',[],'Ytick',[]);   %  numbers, not physical dimensions
drawnow
