function runHalfFin(coarse_run,short_run,LB,bB,sw,method)
% runHalfFin  Start a half-fin simulation
%
% Synopsis:  runHalfFin
%            runHalfFin(coarse_run)
%            runHalfFin(coarse_run,short_run)
%            runHalfFin(coarse_run,short_run,LB)
%            runHalfFin(coarse_run,short_run,LB,bB)
%            runHalfFin(coarse_run,short_run,LB,bB,sw)
%            runHalfFin(coarse_run,short_run,LB,bB,sw,method)
%
% Input: coarse_run = flag to indicate whether a coarse mesh or fine mesh is used
%                     Default: coarse_run = 1, use coarse mesh
%        short_run  = flag to indicate whether a short or long simulation is run
%                     Default: short_run = 1, short run: tsop = 4
%        LB = L/B ratio used to specify fin length.  L = total length of fin from tip
%             to base of the domain

global FPOUT  BASEFNAME    %  Handle to output file

Lx = 5e-3;          %   length of domain in x-direction (m)
Ly = 5e-2;          %   height of domain in y-direction (m)

if nargin<1 | isempty(coarse_run),  coarse_run = 1;  end
if nargin<2 | isempty(short_run),   short_run = 1;   end
if nargin<3 | isempty(LB),  LB = 0.8875;   end   %  optimum L/B ratio
if nargin<4 | isempty(bB),  bB = 0.0125;   end   %  optimum b/B ratio
if nargin<5 | isempty(sw),  sw = 0.275;    end   %  optimum s/w ratio
if nargin<6,  method = 1;      end

fprintf('%s started %s\n',mfilename,datestr(now))

if coarse_run
	dxref = 5e-4;    dyref = 2e-3;  dt = 0.15;
else
	dxref = 2.5e-4;  dyref = 1e-3;  dt = 0.02;
end

if short_run
  tstop = 40*dt;
else
  tstop = 750;
end

BASEFNAME = sprintf('HF_LB%03d_bB%03d_sw%03d_ts%d',...
	                   fix(1000*LB),fix(1000*bB),fix(1000*sw),fix(tstop));
fname = sprintf('%s.out',BASEFNAME);
FPOUT = fopen(fname,'w');
PCmain('halfFin',method,Lx,Ly,LB,bB,sw,dxref,dyref,dt,tstop)
if FPOUT~=1 & FPOUT~=2,  fclose(FPOUT);   end
fprintf('\n%s ended %s\n',mfilename,datestr(now))
