function transientDirPlots(dirname)
% transientDirPlots  Draw transient response for data in sequence of .mat files
%
% Synopsis:  transientDirPlots(dirname)
%
% Input:  dirname = directory containing the .mat files

if nargin<1
	D = dir('*.mat');
else
	D = dir(sprintf('%s/*.mat',dirname));
end
fig = [];   %   figf = [];

fprintf('\n    LB        bB        sw      tstar     tinf      fstar\n');
for i=1:size(D,1)
  theFile = D(i).name;
  if nargin<1
	  fname = theFile;
  else
    fname = sprintf('%s/%s',dirname,theFile);
  end
	if findstr(fname,'scalar')
		load(fname);
    istop = min( find(tt==0) ) - 1;
    if isempty(istop),  istop=length(tt);  end
		% fprintf('scalar data from %s\n',theFile);
		% --- Extract values from the file name
		LB = getValInStr(theFile,'LB','_')/1000;
		bB = getValInStr(theFile,'bB','_')/1000;
		sw = getValInStr(theFile,'sw','_')/1000;

		fig = doPlot(fig,tt(1:istop),TPROBE(1:istop,1),MELTFRAC(1:istop),LB,bB,sw);
	end
end

axTb = subplot(1,2,1);
grid('on');  xlabel('time (s)');  ylabel('T_b  (C)','Rotation',0)
axis([0 750 0 100]);
set(axTb,'XTick',[0 250 500 750]);
set(axTb,'xTickLabel',strvcat('0','250','500','750'))

axf = subplot(1,2,2);
grid('on');  xlabel('time (s)');  ylabel('f','Rotation',0)
axis([0 750 0 1])
set(axf,'XTick',[0 250 500 750]);
set(axf,'xTickLabel',strvcat('0','250','500','750'))

% ============================================================
function fig = doPlot(fig,t,Tb,f,LB,bB,sw)

if isempty(fig), 	fig = figure;  end
figure(fig);

% --- Find tstar, tinf, and fstar.  Set safe values if not found
istar = min( find(Tb>80) ) - 1;
iinf  = min( find(f>=1) ) - 1;
if isempty(istar)
  tstar = -t(end);  fstar = -1;
  fprintf('\n\tistar not found:  min(Tb), max(Tb), max(t) = %g  %g %g\n',min(Tb),max(Tb),max(t))
else
  tstar = t(istar);   fstar = f(istar);
end
if isempty(iinf)
  tinf = -t(end);
else
  tinf = t(iinf);
end
fprintf('%8.5f  %8.5f  %8.5f  %8.2f  %8.2f  %8.6f\n',LB,bB,sw,tstar,tinf,fstar);

% --- Use two subplots inside figure window that is saved
axTb = subplot(1,2,1);
hold on
plot(t,Tb,'--')

axf = subplot(1,2,2);
hold on
plot(t,f,'--')

% =======================================================================
function v = getValInStr(s,sL,sr)
% getValInStr  Get value embedded in a string
%
% Synopsis:  v = getValInStr(s,sL,sr)
%
% Input:  s = string
%         sL = string that brackets value on the left
%         sr = string that brackets value on the right
%
% Ouput:  v = value embedded in string, and surrounded by sL and sr
%
% Example:  If s = 'abc_x100_y200rst', then v = getValInStr(s,'x','_')
%           returns the numerical value 100, and v = getValInStr(s,'y','rst')
%           returns the numerical value 200

% --- Find indices in string that 
ib = 1 + (length(sL)-1) + max(strfind(s,sL)); %  index of beginning of str representation of value
ie = ib + min(strfind(s(ib:end),sr)) - 2;   %  end of str representation
v = str2num(s(ib:ie));
if isempty(v)
  warning(sprintf('Numerical value not found:  string is %s',s(ib:ie)));
end
